@@ -13,13 +13,13 @@ use JetBrains\PhpStorm\Internal\PhpStormStubsElementAvailable;
  * @param string $service [optional] <p>
  * The service to connect to. If service is a name, it is translated to the corresponding port number.
  * </p>
- * @param array $hints [optional] <p>
+ * @param array $hints <p>
  * Hints provide criteria for selecting addresses returned. You may specify the hints as defined by getadrinfo.
  * </p>
  * @return AddressInfo[]|false of AddrInfo resource handles that can be used with the other socket_addrinfo functions.
  * @since 7.2
  */
-function socket_addrinfo_lookup(string $host, ?string $service, array $hints): array|false {}
+function socket_addrinfo_lookup(string $host, ?string $service, array $hints = []): array|false {}
 
 /**
  * Create a Socket resource, and connect it to the provided AddrInfo resource.<br/>
@@ -389,7 +389,7 @@ function socket_close(Socket $socket): void {}
  * @param string $data <p>
  * The buffer to be written.
  * </p>
- * @param int|null $length [optional] <p>
+ * @param int|null $length <p>
  * The optional parameter <i>length</i> can specify an
  * alternate length of bytes written to the socket. If this length is
  * greater than the buffer length, it is silently truncated to the length
@@ -407,7 +407,7 @@ function socket_close(Socket $socket): void {}
  * === operator to check for <b>FALSE</b> in case of an
  * error.
  */
-function socket_write(Socket $socket, string $data, ?int $length = 0): int|false {}
+function socket_write(Socket $socket, string $data, ?int $length = null): int|false {}
 
 /**
  * Reads a maximum of length bytes from a socket
@@ -517,7 +517,7 @@ function socket_getpeername(Socket $socket, &$address, &$port = null): bool {}
  * or the pathname of a Unix domain socket, if the socket family is
  * <b>AF_UNIX</b>.
  * </p>
- * @param int|null $port [optional] <p>
+ * @param int|null $port <p>
  * The <i>port</i> parameter is only used and is mandatory
  * when connecting to an <b>AF_INET</b> or an
  * <b>AF_INET6</b> socket, and designates
@@ -532,7 +532,7 @@ function socket_getpeername(Socket $socket, &$address, &$port = null): bool {}
  * If the socket is non-blocking then this function returns <b>FALSE</b> with an
  * error Operation now in progress.
  */
-function socket_connect(Socket $socket, string $address, ?int $port = 0): bool {}
+function socket_connect(Socket $socket, string $address, ?int $port = null): bool {}
 
 /**
  * Return a string describing a socket error
@@ -849,14 +849,14 @@ function socket_recvmsg(
  * @param string $address <p>
  * IP address of the remote host.
  * </p>
- * @param int|null $port [optional] <p>
+ * @param int|null $port <p>
  * <i>port</i> is the remote port number at which the data
  * will be sent.
  * </p>
  * @return int|false <b>socket_sendto</b> returns the number of bytes sent to the
  * remote host, or <b>FALSE</b> if an error occurred.
  */
-function socket_sendto(Socket $socket, string $data, int $length, int $flags, string $address, ?int $port = 0): int|false {}
+function socket_sendto(Socket $socket, string $data, int $length, int $flags, string $address, ?int $port = null): int|false {}
 
 /**
  * Gets socket options for the socket
